@@ -1,21 +1,8 @@
 /*
  *  kaeventformatter.cpp  -  converts KAlarmCal::KAEvent properties to text
- *  Copyright © 2010-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2010-2019 David Jarvie <djarvie@kde.org>
  *
- *  This library is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at your
- *  option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "kaeventformatter.h"
@@ -24,7 +11,7 @@
 #include "kaevent.h"
 #include "datetime.h"
 
-#include <kcalutils/incidenceformatter.h>
+#include <KCalUtils/IncidenceFormatter>
 
 #include <klocalizedstring.h>
 
